# HL-MakePIP
Makes a project pip project


pip install "git+https://github.com/USERNAME/REPO_NAME.git@BRANCH_OR_TAG"




min required to make a pip project

- pyproject.toml
- save file in .toml ^
- build project w/ build
- provides files for git
- pypi for upload


Pip has two methods
setup_project_env - Serves to set up a project to be ready for env
register_to_pip - registers the package onto pip.




Rqs:

pip, twine, build


ALSo creates publish.yml
.github/workflows/publish.yml


Should also add those files to .gitignore evneutally 

Consider the "go to github and make pypi enviroment" step